from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSWPCommandArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSWPArchives_sos_pb2 as TSWPArchives__sos__pb2
from . import TSWPCommandArchives_pb2 as TSWPCommandArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSWPCommandArchives_sos.proto',
  package='TSWP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1dTSWPCommandArchives_sos.proto\x12\x04TSWP\x1a\x11TSPMessages.proto\x1a\x16TSWPArchives_sos.proto\x1a\x19TSWPCommandArchives.proto\"\xab\x02\n,CharacterStyleChangePropertyCommand_GArchive\x12\x30\n\x05super\x18\x01 \x02(\x0b\x32!.TSWP.StorageActionCommandArchive\x12\x1e\n\nrange_list\x18\x02 \x03(\x0b\x32\n.TSP.Range\x12\x1c\n\x14range_list_undefined\x18\x03 \x01(\x08\x12\x41\n\x0b\x63hange_list\x18\x04 \x03(\x0b\x32,.TSWP.CharacterStylePropertyChangeSetArchive\x12\x1d\n\x15\x63hange_list_undefined\x18\x05 \x01(\x08\x12)\n!disable_character_style_promotion\x18\x06 \x02(\x08\"\x80\x02\n,ParagraphStyleChangePropertyCommand_GArchive\x12\x30\n\x05super\x18\x01 \x02(\x0b\x32!.TSWP.StorageActionCommandArchive\x12\x1e\n\nrange_list\x18\x02 \x03(\x0b\x32\n.TSP.Range\x12\x1c\n\x14range_list_undefined\x18\x03 \x01(\x08\x12\x41\n\x0b\x63hange_list\x18\x04 \x03(\x0b\x32,.TSWP.ParagraphStylePropertyChangeSetArchive\x12\x1d\n\x15\x63hange_list_undefined\x18\x05 \x01(\x08')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSWPArchives__sos__pb2.DESCRIPTOR,TSWPCommandArchives__pb2.DESCRIPTOR,])




_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE = _descriptor.Descriptor(
  name='CharacterStyleChangePropertyCommand_GArchive',
  full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.range_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list_undefined', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.range_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.change_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list_undefined', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.change_list_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_character_style_promotion', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.disable_character_style_promotion', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=409,
)


_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE = _descriptor.Descriptor(
  name='ParagraphStyleChangePropertyCommand_GArchive',
  full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.range_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list_undefined', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.range_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.change_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list_undefined', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.change_list_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=668,
)

_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['super'].message_type = TSWPCommandArchives__pb2._STORAGEACTIONCOMMANDARCHIVE
_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['range_list'].message_type = TSPMessages__pb2._RANGE
_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['change_list'].message_type = TSWPArchives__sos__pb2._CHARACTERSTYLEPROPERTYCHANGESETARCHIVE
_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['super'].message_type = TSWPCommandArchives__pb2._STORAGEACTIONCOMMANDARCHIVE
_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['range_list'].message_type = TSPMessages__pb2._RANGE
_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['change_list'].message_type = TSWPArchives__sos__pb2._PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['CharacterStyleChangePropertyCommand_GArchive'] = _CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE
DESCRIPTOR.message_types_by_name['ParagraphStyleChangePropertyCommand_GArchive'] = _PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CharacterStyleChangePropertyCommand_GArchive = _reflection.GeneratedProtocolMessageType('CharacterStyleChangePropertyCommand_GArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE,
  __module__ = 'TSWPCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CharacterStyleChangePropertyCommand_GArchive)
  ))
_sym_db.RegisterMessage(CharacterStyleChangePropertyCommand_GArchive)

ParagraphStyleChangePropertyCommand_GArchive = _reflection.GeneratedProtocolMessageType('ParagraphStyleChangePropertyCommand_GArchive', (_message.Message,), dict(
  DESCRIPTOR = _PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE,
  __module__ = 'TSWPCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ParagraphStyleChangePropertyCommand_GArchive)
  ))
_sym_db.RegisterMessage(ParagraphStyleChangePropertyCommand_GArchive)


# @@protoc_insertion_point(module_scope)



from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSAArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSDCommandArchives_pb2 as TSDCommandArchives__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2
from . import TSWPCommandArchives_pb2 as TSWPCommandArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSTArchives_pb2 as TSTArchives__pb2
from . import TSCEArchives_pb2 as TSCEArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSAArchives.proto',
  package='TSA',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x11TSAArchives.proto\x12\x03TSA\x1a\x11TSDArchives.proto\x1a\x18TSDCommandArchives.proto\x1a\x11TSKArchives.proto\x1a\x11TSPMessages.proto\x1a\x12TSWPArchives.proto\x1a\x19TSWPCommandArchives.proto\x1a\x11TSSArchives.proto\x1a\x11TSTArchives.proto\x1a\x12TSCEArchives.proto\"\xaa\x05\n\x0f\x44ocumentArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSK.DocumentArchive\x12\x45\n\x19text_preset_display_items\x18\x02 \x03(\x0b\x32\".TSWP.TextPresetDisplayItemArchive\x12\x19\n\x11\x64ocument_language\x18\x03 \x01(\t\x12*\n\x12\x63\x61lculation_engine\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\nview_state\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x66unction_browser_state\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19tables_custom_format_list\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n!needs_media_compatibility_upgrade\x18\x08 \x01(\x08\x12\x1b\n\x13template_identifier\x18\t \x01(\t\x12+\n\x13shortcut_controller\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x61nnotation_cache_deprecated\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12*\n\x12\x63ustom_format_list\x18\x0c \x01(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x1d\x61nnotation_cache_deprecated_2\x18\r \x01(\x0b\x32\x0e.TSP.Reference\x12:\n2collaborative_media_compatibility_upgrade_did_fail\x18\x0e \x01(\x08\x12\x14\n\x0c\x63\x61n_use_hevc\x18\x0f \x01(\x08\"\x84\x01\n\x1b\x46unctionBrowserStateArchive\x12\x18\n\x10recent_functions\x18\x01 \x03(\r\x12\x16\n\x0e\x62\x61\x63k_functions\x18\x02 \x03(\r\x12\x19\n\x11\x66orward_functions\x18\x03 \x03(\r\x12\x18\n\x10\x63urrent_function\x18\x04 \x01(\r\"\x85\x01\n\x13ThemePresetsArchive\x12-\n\x15\x63\x61ption_style_presets\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference2?\n\textension\x12\x11.TSS.ThemeArchive\x18\xd2\x01 \x01(\x0b\x32\x18.TSA.ThemePresetsArchive\"\xa2\x01\n\x19ShortcutControllerArchive\x12@\n\x07\x65ntries\x18\x01 \x03(\x0b\x32/.TSA.ShortcutControllerArchive.ShortcutMapEntry\x1a\x43\n\x10ShortcutMapEntry\x12\x10\n\x08shortcut\x18\x01 \x02(\t\x12\x1d\n\x05style\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"\x96\x01\n\x1dPropagatePresetCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12-\n\x15preset_change_command\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\x1a\x61lways_preserve_appearance\x18\x03 \x02(\x08\"\xae\x01\n\x16ShortcutCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12!\n\told_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12!\n\tnew_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cold_shortcut\x18\x04 \x01(\t\x12\x14\n\x0cnew_shortcut\x18\x05 \x01(\t\"\x9a\x01\n\x1d\x41\x64\x64\x43ustomFormatCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12/\n\rcustom_format\x18\x02 \x01(\x0b\x32\x18.TSK.CustomFormatArchive\x12$\n\x11\x63ustom_format_key\x18\x03 \x01(\x0b\x32\t.TSP.UUID\"\xd2\x01\n UpdateCustomFormatCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12/\n\rcustom_format\x18\x02 \x01(\x0b\x32\x18.TSK.CustomFormatArchive\x12\x33\n\x11old_custom_format\x18\x03 \x01(\x0b\x32\x18.TSK.CustomFormatArchive\x12$\n\x11\x63ustom_format_key\x18\x04 \x01(\x0b\x32\t.TSP.UUID\"\xd4\x01\n!ReplaceCustomFormatCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12/\n\rcustom_format\x18\x02 \x01(\x0b\x32\x18.TSK.CustomFormatArchive\x12$\n\x11\x63ustom_format_key\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12\x34\n\x12replacement_format\x18\x04 \x01(\x0b\x32\x18.TSK.FormatStructArchive\"\xd8\x02\n,NeedsMediaCompatibilityUpgradeCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n!needs_media_compatibility_upgrade\x18\x02 \x01(\x08\x12-\n%old_needs_media_compatibility_upgrade\x18\x03 \x01(\x08\x12:\n2collaborative_media_compatibility_upgrade_did_fail\x18\x04 \x01(\x08\x12>\n6old_collaborative_media_compatibility_upgrade_did_fail\x18\x05 \x01(\x08\x12\x14\n\x0c\x63\x61n_use_hevc\x18\x06 \x01(\x08\x12\x18\n\x10old_can_use_hevc\x18\x07 \x01(\x08\"\xf4\x01\n\"ChangeDocumentLocaleCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x15\n\rold_locale_id\x18\x02 \x01(\t\x12\x15\n\rnew_locale_id\x18\x03 \x01(\t\x12=\n\x16old_formatting_symbols\x18\x04 \x01(\x0b\x32\x1d.TSK.FormattingSymbolsArchive\x12=\n\x16new_formatting_symbols\x18\x05 \x01(\x0b\x32\x1d.TSK.FormattingSymbolsArchive\"\xa9\x02\n,InducedVerifyObjectsWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\x0eobject_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12 \n\x18object_id_list_undefined\x18\x03 \x01(\x08\x12\'\n\x1fserver_object_s_o_s_string_list\x18\x04 \x03(\t\x12\x31\n)server_object_s_o_s_string_list_undefined\x18\x05 \x01(\x08\x12\x16\n\x0epending_recalc\x18\x06 \x02(\x08\x12\x1c\n\x14remote_data_sync_key\x18\x07 \x02(\x01\"\xd5\x01\n5InducedVerifyTransformHistoryWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x44\n server_operation_storage_entries\x18\x02 \x03(\x0b\x32\x1a.TSK.OperationStorageEntry\x12\x32\n*server_operation_storage_entries_undefined\x18\x03 \x01(\x08\"a\n$StyleUpdatePropertyMapCommandArchive\x12\x39\n\x05super\x18\x01 \x01(\x0b\x32*.TSWP.StyleUpdatePropertyMapCommandArchive\"\xba\x01\n\x1eRemoteDataChangeCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x32\n\tvalue_map\x18\x02 \x02(\x0b\x32\x1f.TSCE.RemoteDataValueMapArchive\x12\"\n\x06quotes\x18\x03 \x03(\x0b\x32\x12.TSCE.StockArchive\x12\x1c\n\x14remote_data_sync_key\x18\x04 \x02(\x01\"\xea\x02\n!GalleryInfoSetValueCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12#\n\x0cinfo_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12*\n\x08property\x18\x03 \x01(\x0e\x32\x18.TSA.GalleryInfoProperty\x12\x43\n\x05value\x18\x04 \x01(\x0b\x32\x34.TSA.GalleryInfoSetValueCommandArchive.PropertyValue\x12G\n\told_value\x18\x05 \x01(\x0b\x32\x34.TSA.GalleryInfoSetValueCommandArchive.PropertyValue\x1a\x42\n\rPropertyValue\x12\x31\n\x0c\x63\x61ption_mode\x18\x01 \x01(\x0e\x32\x1b.TSA.GalleryInfoCaptionMode\"\xc9\x01\n\x1dGalleryItemSetGeometryCommand\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12#\n\x0citem_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12\x1a\n\x06offset\x18\x03 \x01(\x0b\x32\n.TSP.Point\x12\x10\n\x05scale\x18\x04 \x01(\x02:\x01\x31\x12\x1e\n\nold_offset\x18\x05 \x01(\x0b\x32\n.TSP.Point\x12\x11\n\told_scale\x18\x06 \x01(\x02\"\x83\x03\n\x0bGalleryItem\x12\x1a\n\x06offset\x18\x01 \x01(\x0b\x32\n.TSP.Point\x12\r\n\x05scale\x18\x02 \x01(\x02\x12&\n\nimage_data\x18\x03 \x01(\x0b\x32\x12.TSP.DataReference\x12\x30\n\x14thumbnail_image_data\x18\x04 \x01(\x0b\x32\x12.TSP.DataReference\x12\x37\n\x11image_adjustments\x18\x05 \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12/\n\x13\x61\x64justed_image_data\x18\x06 \x01(\x0b\x32\x12.TSP.DataReference\x12\x39\n\x1dthumbnail_adjusted_image_data\x18\x07 \x01(\x0b\x32\x12.TSP.DataReference\x12\'\n\x0f\x63\x61ption_storage\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12!\n\x19\x61\x63\x63\x65ssibility_description\x18\t \x01(\t\"\xc0\x01\n\x0bGalleryInfo\x12\x1d\n\x05items\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x0c\x63\x61ption_mode\x18\x02 \x01(\x0e\x32\x17.TSA.GalleryCaptionMode\x12\'\n\x0f\x63\x61ption_storage\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference2:\n\x0cgallery_info\x12\x11.TSD.ImageArchive\x18\xc8\x01 \x01(\x0b\x32\x10.TSA.GalleryInfo\"\xb2\x01\n\x1bGallerySelectionTransformer\x12\x37\n\x05super\x18\x01 \x02(\x0b\x32(.TSD.DrawableSelectionTransformerArchive\x12(\n\x11gallery_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12\x30\n\x19\x63\x61ption_storage_uuid_path\x18\x03 \x01(\x0b\x32\r.TSP.UUIDPath\"]\n\x14GalleryItemSelection\x12&\n\x0e\x64isplayed_item\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05items\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"\x9b\x01\n\x1fGalleryItemSelectionTransformer\x12\x46\n\x12transformer_helper\x18\x01 \x01(\x0b\x32*.TSA.GalleryItemSelectionTransformerHelper\x12\x30\n\x19\x63\x61ption_storage_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\"\x80\x01\n%GalleryItemSelectionTransformerHelper\x12/\n\x18\x64isplayed_item_uuid_path\x18\x01 \x01(\x0b\x32\r.TSP.UUIDPath\x12&\n\x0fitem_uuid_paths\x18\x02 \x03(\x0b\x32\r.TSP.UUIDPath\"\xed\x02\n\x1aGalleryItemSetValueCommand\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12#\n\x0citem_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12*\n\x08property\x18\x03 \x01(\x0e\x32\x18.TSA.GalleryItemProperty\x12<\n\x05value\x18\x04 \x01(\x0b\x32-.TSA.GalleryItemSetValueCommand.PropertyValue\x12@\n\told_value\x18\x05 \x01(\x0b\x32-.TSA.GalleryItemSetValueCommand.PropertyValue\x1aZ\n\rPropertyValue\x12&\n\nimage_data\x18\x01 \x01(\x0b\x32\x12.TSP.DataReference\x12!\n\x19\x61\x63\x63\x65ssibility_description\x18\x02 \x01(\t\"\xb0\x01\n\x0cWebVideoInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\x12-\n\x11poster_image_data\x18\x02 \x01(\x0b\x32\x12.TSP.DataReference\x12%\n\x0b\x61ttribution\x18\x03 \x01(\x0b\x32\x10.TSD.Attribution2=\n\x0eweb_video_info\x12\x11.TSD.ImageArchive\x18\xac\x02 \x01(\x0b\x32\x11.TSA.WebVideoInfo\"\\\n\x17\x43\x61ptionPlacementArchive\x12\x1f\n\x17\x63\x61ption_anchor_location\x18\x01 \x01(\x05\x12 \n\x18\x64rawable_anchor_location\x18\x02 \x01(\x05\"\x8e\x01\n\x12\x43\x61ptionInfoArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSWP.ShapeInfoArchive\x12!\n\tplacement\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\rchildInfoKind\x18\x03 \x01(\x0e\x32\x17.TSD.CaptionOrTitleKind\"\xca\x01\n\x1cTitlePlacementCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x38\n\x17placing_child_info_kind\x18\x02 \x01(\x0e\x32\x17.TSD.CaptionOrTitleKind\x12!\n\tplacement\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rold_placement\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference*\x81\x01\n\x16GalleryInfoCaptionMode\x12\x1e\n\x1aGalleryInfoCaptionModeNone\x10\x00\x12\"\n\x1eGalleryInfoCaptionModePerImage\x10\x01\x12#\n\x1fGalleryInfoCaptionModeAllImages\x10\x02*5\n\x13GalleryInfoProperty\x12\x1e\n\x1aGalleryInfoCaptionProperty\x10\x00*q\n\x12GalleryCaptionMode\x12\x1a\n\x16GalleryCaptionModeNone\x10\x00\x12\x1e\n\x1aGalleryCaptionModePerImage\x10\x01\x12\x1f\n\x1bGalleryCaptionModeAllImages\x10\x02*\x93\x01\n\x13GalleryItemProperty\x12 \n\x1cGalleryItemPropertyImageData\x10\x00\x12)\n%GalleryItemPropertyThumbnailImageData\x10\x01\x12/\n+GalleryItemPropertyAccessibilityDescription\x10\x02')
  ,
  dependencies=[TSDArchives__pb2.DESCRIPTOR,TSDCommandArchives__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSWPCommandArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSTArchives__pb2.DESCRIPTOR,TSCEArchives__pb2.DESCRIPTOR,])

_GALLERYINFOCAPTIONMODE = _descriptor.EnumDescriptor(
  name='GalleryInfoCaptionMode',
  full_name='TSA.GalleryInfoCaptionMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GalleryInfoCaptionModeNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GalleryInfoCaptionModePerImage', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GalleryInfoCaptionModeAllImages', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6359,
  serialized_end=6488,
)
_sym_db.RegisterEnumDescriptor(_GALLERYINFOCAPTIONMODE)

GalleryInfoCaptionMode = enum_type_wrapper.EnumTypeWrapper(_GALLERYINFOCAPTIONMODE)
_GALLERYINFOPROPERTY = _descriptor.EnumDescriptor(
  name='GalleryInfoProperty',
  full_name='TSA.GalleryInfoProperty',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GalleryInfoCaptionProperty', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6490,
  serialized_end=6543,
)
_sym_db.RegisterEnumDescriptor(_GALLERYINFOPROPERTY)

GalleryInfoProperty = enum_type_wrapper.EnumTypeWrapper(_GALLERYINFOPROPERTY)
_GALLERYCAPTIONMODE = _descriptor.EnumDescriptor(
  name='GalleryCaptionMode',
  full_name='TSA.GalleryCaptionMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GalleryCaptionModeNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GalleryCaptionModePerImage', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GalleryCaptionModeAllImages', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6545,
  serialized_end=6658,
)
_sym_db.RegisterEnumDescriptor(_GALLERYCAPTIONMODE)

GalleryCaptionMode = enum_type_wrapper.EnumTypeWrapper(_GALLERYCAPTIONMODE)
_GALLERYITEMPROPERTY = _descriptor.EnumDescriptor(
  name='GalleryItemProperty',
  full_name='TSA.GalleryItemProperty',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GalleryItemPropertyImageData', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GalleryItemPropertyThumbnailImageData', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GalleryItemPropertyAccessibilityDescription', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6661,
  serialized_end=6808,
)
_sym_db.RegisterEnumDescriptor(_GALLERYITEMPROPERTY)

GalleryItemProperty = enum_type_wrapper.EnumTypeWrapper(_GALLERYITEMPROPERTY)
GalleryInfoCaptionModeNone = 0
GalleryInfoCaptionModePerImage = 1
GalleryInfoCaptionModeAllImages = 2
GalleryInfoCaptionProperty = 0
GalleryCaptionModeNone = 0
GalleryCaptionModePerImage = 1
GalleryCaptionModeAllImages = 2
GalleryItemPropertyImageData = 0
GalleryItemPropertyThumbnailImageData = 1
GalleryItemPropertyAccessibilityDescription = 2



_DOCUMENTARCHIVE = _descriptor.Descriptor(
  name='DocumentArchive',
  full_name='TSA.DocumentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.DocumentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_preset_display_items', full_name='TSA.DocumentArchive.text_preset_display_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_language', full_name='TSA.DocumentArchive.document_language', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calculation_engine', full_name='TSA.DocumentArchive.calculation_engine', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_state', full_name='TSA.DocumentArchive.view_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_browser_state', full_name='TSA.DocumentArchive.function_browser_state', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tables_custom_format_list', full_name='TSA.DocumentArchive.tables_custom_format_list', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_media_compatibility_upgrade', full_name='TSA.DocumentArchive.needs_media_compatibility_upgrade', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template_identifier', full_name='TSA.DocumentArchive.template_identifier', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortcut_controller', full_name='TSA.DocumentArchive.shortcut_controller', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation_cache_deprecated', full_name='TSA.DocumentArchive.annotation_cache_deprecated', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_list', full_name='TSA.DocumentArchive.custom_format_list', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation_cache_deprecated_2', full_name='TSA.DocumentArchive.annotation_cache_deprecated_2', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaborative_media_compatibility_upgrade_did_fail', full_name='TSA.DocumentArchive.collaborative_media_compatibility_upgrade_did_fail', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_use_hevc', full_name='TSA.DocumentArchive.can_use_hevc', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=897,
)


_FUNCTIONBROWSERSTATEARCHIVE = _descriptor.Descriptor(
  name='FunctionBrowserStateArchive',
  full_name='TSA.FunctionBrowserStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recent_functions', full_name='TSA.FunctionBrowserStateArchive.recent_functions', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='back_functions', full_name='TSA.FunctionBrowserStateArchive.back_functions', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_functions', full_name='TSA.FunctionBrowserStateArchive.forward_functions', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_function', full_name='TSA.FunctionBrowserStateArchive.current_function', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=1032,
)


_THEMEPRESETSARCHIVE = _descriptor.Descriptor(
  name='ThemePresetsArchive',
  full_name='TSA.ThemePresetsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caption_style_presets', full_name='TSA.ThemePresetsArchive.caption_style_presets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='extension', full_name='TSA.ThemePresetsArchive.extension', index=0,
      number=210, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1168,
)


_SHORTCUTCONTROLLERARCHIVE_SHORTCUTMAPENTRY = _descriptor.Descriptor(
  name='ShortcutMapEntry',
  full_name='TSA.ShortcutControllerArchive.ShortcutMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortcut', full_name='TSA.ShortcutControllerArchive.ShortcutMapEntry.shortcut', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSA.ShortcutControllerArchive.ShortcutMapEntry.style', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1333,
)

_SHORTCUTCONTROLLERARCHIVE = _descriptor.Descriptor(
  name='ShortcutControllerArchive',
  full_name='TSA.ShortcutControllerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSA.ShortcutControllerArchive.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SHORTCUTCONTROLLERARCHIVE_SHORTCUTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1333,
)


_PROPAGATEPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='PropagatePresetCommandArchive',
  full_name='TSA.PropagatePresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.PropagatePresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_change_command', full_name='TSA.PropagatePresetCommandArchive.preset_change_command', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='always_preserve_appearance', full_name='TSA.PropagatePresetCommandArchive.always_preserve_appearance', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1336,
  serialized_end=1486,
)


_SHORTCUTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ShortcutCommandArchive',
  full_name='TSA.ShortcutCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.ShortcutCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_style', full_name='TSA.ShortcutCommandArchive.old_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_style', full_name='TSA.ShortcutCommandArchive.new_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_shortcut', full_name='TSA.ShortcutCommandArchive.old_shortcut', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_shortcut', full_name='TSA.ShortcutCommandArchive.new_shortcut', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1489,
  serialized_end=1663,
)


_ADDCUSTOMFORMATCOMMANDARCHIVE = _descriptor.Descriptor(
  name='AddCustomFormatCommandArchive',
  full_name='TSA.AddCustomFormatCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.AddCustomFormatCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format', full_name='TSA.AddCustomFormatCommandArchive.custom_format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_key', full_name='TSA.AddCustomFormatCommandArchive.custom_format_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1666,
  serialized_end=1820,
)


_UPDATECUSTOMFORMATCOMMANDARCHIVE = _descriptor.Descriptor(
  name='UpdateCustomFormatCommandArchive',
  full_name='TSA.UpdateCustomFormatCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.UpdateCustomFormatCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format', full_name='TSA.UpdateCustomFormatCommandArchive.custom_format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_custom_format', full_name='TSA.UpdateCustomFormatCommandArchive.old_custom_format', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_key', full_name='TSA.UpdateCustomFormatCommandArchive.custom_format_key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1823,
  serialized_end=2033,
)


_REPLACECUSTOMFORMATCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ReplaceCustomFormatCommandArchive',
  full_name='TSA.ReplaceCustomFormatCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.ReplaceCustomFormatCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format', full_name='TSA.ReplaceCustomFormatCommandArchive.custom_format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_key', full_name='TSA.ReplaceCustomFormatCommandArchive.custom_format_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacement_format', full_name='TSA.ReplaceCustomFormatCommandArchive.replacement_format', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2036,
  serialized_end=2248,
)


_NEEDSMEDIACOMPATIBILITYUPGRADECOMMANDARCHIVE = _descriptor.Descriptor(
  name='NeedsMediaCompatibilityUpgradeCommandArchive',
  full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_media_compatibility_upgrade', full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive.needs_media_compatibility_upgrade', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_needs_media_compatibility_upgrade', full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive.old_needs_media_compatibility_upgrade', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaborative_media_compatibility_upgrade_did_fail', full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive.collaborative_media_compatibility_upgrade_did_fail', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_collaborative_media_compatibility_upgrade_did_fail', full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive.old_collaborative_media_compatibility_upgrade_did_fail', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_use_hevc', full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive.can_use_hevc', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_can_use_hevc', full_name='TSA.NeedsMediaCompatibilityUpgradeCommandArchive.old_can_use_hevc', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2251,
  serialized_end=2595,
)


_CHANGEDOCUMENTLOCALECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ChangeDocumentLocaleCommandArchive',
  full_name='TSA.ChangeDocumentLocaleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.ChangeDocumentLocaleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_locale_id', full_name='TSA.ChangeDocumentLocaleCommandArchive.old_locale_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_locale_id', full_name='TSA.ChangeDocumentLocaleCommandArchive.new_locale_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_formatting_symbols', full_name='TSA.ChangeDocumentLocaleCommandArchive.old_formatting_symbols', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_formatting_symbols', full_name='TSA.ChangeDocumentLocaleCommandArchive.new_formatting_symbols', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2598,
  serialized_end=2842,
)


_INDUCEDVERIFYOBJECTSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyObjectsWithServerCommandArchive',
  full_name='TSA.InducedVerifyObjectsWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.InducedVerifyObjectsWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_id_list', full_name='TSA.InducedVerifyObjectsWithServerCommandArchive.object_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_id_list_undefined', full_name='TSA.InducedVerifyObjectsWithServerCommandArchive.object_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_object_s_o_s_string_list', full_name='TSA.InducedVerifyObjectsWithServerCommandArchive.server_object_s_o_s_string_list', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_object_s_o_s_string_list_undefined', full_name='TSA.InducedVerifyObjectsWithServerCommandArchive.server_object_s_o_s_string_list_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending_recalc', full_name='TSA.InducedVerifyObjectsWithServerCommandArchive.pending_recalc', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_data_sync_key', full_name='TSA.InducedVerifyObjectsWithServerCommandArchive.remote_data_sync_key', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2845,
  serialized_end=3142,
)


_INDUCEDVERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyTransformHistoryWithServerCommandArchive',
  full_name='TSA.InducedVerifyTransformHistoryWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.InducedVerifyTransformHistoryWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_operation_storage_entries', full_name='TSA.InducedVerifyTransformHistoryWithServerCommandArchive.server_operation_storage_entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_operation_storage_entries_undefined', full_name='TSA.InducedVerifyTransformHistoryWithServerCommandArchive.server_operation_storage_entries_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3145,
  serialized_end=3358,
)


_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleUpdatePropertyMapCommandArchive',
  full_name='TSA.StyleUpdatePropertyMapCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.StyleUpdatePropertyMapCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3360,
  serialized_end=3457,
)


_REMOTEDATACHANGECOMMANDARCHIVE = _descriptor.Descriptor(
  name='RemoteDataChangeCommandArchive',
  full_name='TSA.RemoteDataChangeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.RemoteDataChangeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_map', full_name='TSA.RemoteDataChangeCommandArchive.value_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quotes', full_name='TSA.RemoteDataChangeCommandArchive.quotes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_data_sync_key', full_name='TSA.RemoteDataChangeCommandArchive.remote_data_sync_key', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3460,
  serialized_end=3646,
)


_GALLERYINFOSETVALUECOMMANDARCHIVE_PROPERTYVALUE = _descriptor.Descriptor(
  name='PropertyValue',
  full_name='TSA.GalleryInfoSetValueCommandArchive.PropertyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caption_mode', full_name='TSA.GalleryInfoSetValueCommandArchive.PropertyValue.caption_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3945,
  serialized_end=4011,
)

_GALLERYINFOSETVALUECOMMANDARCHIVE = _descriptor.Descriptor(
  name='GalleryInfoSetValueCommandArchive',
  full_name='TSA.GalleryInfoSetValueCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.GalleryInfoSetValueCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info_id_path', full_name='TSA.GalleryInfoSetValueCommandArchive.info_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='TSA.GalleryInfoSetValueCommandArchive.property', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TSA.GalleryInfoSetValueCommandArchive.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_value', full_name='TSA.GalleryInfoSetValueCommandArchive.old_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GALLERYINFOSETVALUECOMMANDARCHIVE_PROPERTYVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3649,
  serialized_end=4011,
)


_GALLERYITEMSETGEOMETRYCOMMAND = _descriptor.Descriptor(
  name='GalleryItemSetGeometryCommand',
  full_name='TSA.GalleryItemSetGeometryCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.GalleryItemSetGeometryCommand.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id_path', full_name='TSA.GalleryItemSetGeometryCommand.item_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSA.GalleryItemSetGeometryCommand.offset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale', full_name='TSA.GalleryItemSetGeometryCommand.scale', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_offset', full_name='TSA.GalleryItemSetGeometryCommand.old_offset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_scale', full_name='TSA.GalleryItemSetGeometryCommand.old_scale', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4014,
  serialized_end=4215,
)


_GALLERYITEM = _descriptor.Descriptor(
  name='GalleryItem',
  full_name='TSA.GalleryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSA.GalleryItem.offset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale', full_name='TSA.GalleryItem.scale', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_data', full_name='TSA.GalleryItem.image_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_image_data', full_name='TSA.GalleryItem.thumbnail_image_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_adjustments', full_name='TSA.GalleryItem.image_adjustments', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_image_data', full_name='TSA.GalleryItem.adjusted_image_data', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_adjusted_image_data', full_name='TSA.GalleryItem.thumbnail_adjusted_image_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_storage', full_name='TSA.GalleryItem.caption_storage', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accessibility_description', full_name='TSA.GalleryItem.accessibility_description', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4218,
  serialized_end=4605,
)


_GALLERYINFO = _descriptor.Descriptor(
  name='GalleryInfo',
  full_name='TSA.GalleryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='TSA.GalleryInfo.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_mode', full_name='TSA.GalleryInfo.caption_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_storage', full_name='TSA.GalleryInfo.caption_storage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='gallery_info', full_name='TSA.GalleryInfo.gallery_info', index=0,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4608,
  serialized_end=4800,
)


_GALLERYSELECTIONTRANSFORMER = _descriptor.Descriptor(
  name='GallerySelectionTransformer',
  full_name='TSA.GallerySelectionTransformer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.GallerySelectionTransformer.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gallery_uuid_path', full_name='TSA.GallerySelectionTransformer.gallery_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_storage_uuid_path', full_name='TSA.GallerySelectionTransformer.caption_storage_uuid_path', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4803,
  serialized_end=4981,
)


_GALLERYITEMSELECTION = _descriptor.Descriptor(
  name='GalleryItemSelection',
  full_name='TSA.GalleryItemSelection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='displayed_item', full_name='TSA.GalleryItemSelection.displayed_item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='TSA.GalleryItemSelection.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4983,
  serialized_end=5076,
)


_GALLERYITEMSELECTIONTRANSFORMER = _descriptor.Descriptor(
  name='GalleryItemSelectionTransformer',
  full_name='TSA.GalleryItemSelectionTransformer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='TSA.GalleryItemSelectionTransformer.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_storage_uuid_path', full_name='TSA.GalleryItemSelectionTransformer.caption_storage_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5079,
  serialized_end=5234,
)


_GALLERYITEMSELECTIONTRANSFORMERHELPER = _descriptor.Descriptor(
  name='GalleryItemSelectionTransformerHelper',
  full_name='TSA.GalleryItemSelectionTransformerHelper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='displayed_item_uuid_path', full_name='TSA.GalleryItemSelectionTransformerHelper.displayed_item_uuid_path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_uuid_paths', full_name='TSA.GalleryItemSelectionTransformerHelper.item_uuid_paths', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5237,
  serialized_end=5365,
)


_GALLERYITEMSETVALUECOMMAND_PROPERTYVALUE = _descriptor.Descriptor(
  name='PropertyValue',
  full_name='TSA.GalleryItemSetValueCommand.PropertyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_data', full_name='TSA.GalleryItemSetValueCommand.PropertyValue.image_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accessibility_description', full_name='TSA.GalleryItemSetValueCommand.PropertyValue.accessibility_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5643,
  serialized_end=5733,
)

_GALLERYITEMSETVALUECOMMAND = _descriptor.Descriptor(
  name='GalleryItemSetValueCommand',
  full_name='TSA.GalleryItemSetValueCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.GalleryItemSetValueCommand.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id_path', full_name='TSA.GalleryItemSetValueCommand.item_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='TSA.GalleryItemSetValueCommand.property', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TSA.GalleryItemSetValueCommand.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_value', full_name='TSA.GalleryItemSetValueCommand.old_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GALLERYITEMSETVALUECOMMAND_PROPERTYVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5368,
  serialized_end=5733,
)


_WEBVIDEOINFO = _descriptor.Descriptor(
  name='WebVideoInfo',
  full_name='TSA.WebVideoInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='TSA.WebVideoInfo.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poster_image_data', full_name='TSA.WebVideoInfo.poster_image_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribution', full_name='TSA.WebVideoInfo.attribution', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='web_video_info', full_name='TSA.WebVideoInfo.web_video_info', index=0,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5736,
  serialized_end=5912,
)


_CAPTIONPLACEMENTARCHIVE = _descriptor.Descriptor(
  name='CaptionPlacementArchive',
  full_name='TSA.CaptionPlacementArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caption_anchor_location', full_name='TSA.CaptionPlacementArchive.caption_anchor_location', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_anchor_location', full_name='TSA.CaptionPlacementArchive.drawable_anchor_location', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5914,
  serialized_end=6006,
)


_CAPTIONINFOARCHIVE = _descriptor.Descriptor(
  name='CaptionInfoArchive',
  full_name='TSA.CaptionInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.CaptionInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement', full_name='TSA.CaptionInfoArchive.placement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='childInfoKind', full_name='TSA.CaptionInfoArchive.childInfoKind', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6009,
  serialized_end=6151,
)


_TITLEPLACEMENTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='TitlePlacementCommandArchive',
  full_name='TSA.TitlePlacementCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.TitlePlacementCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placing_child_info_kind', full_name='TSA.TitlePlacementCommandArchive.placing_child_info_kind', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement', full_name='TSA.TitlePlacementCommandArchive.placement', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_placement', full_name='TSA.TitlePlacementCommandArchive.old_placement', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6154,
  serialized_end=6356,
)

_DOCUMENTARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._DOCUMENTARCHIVE
_DOCUMENTARCHIVE.fields_by_name['text_preset_display_items'].message_type = TSWPArchives__pb2._TEXTPRESETDISPLAYITEMARCHIVE
_DOCUMENTARCHIVE.fields_by_name['calculation_engine'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['view_state'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['function_browser_state'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['tables_custom_format_list'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['shortcut_controller'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['annotation_cache_deprecated'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['custom_format_list'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['annotation_cache_deprecated_2'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['caption_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_SHORTCUTCONTROLLERARCHIVE_SHORTCUTMAPENTRY.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_SHORTCUTCONTROLLERARCHIVE_SHORTCUTMAPENTRY.containing_type = _SHORTCUTCONTROLLERARCHIVE
_SHORTCUTCONTROLLERARCHIVE.fields_by_name['entries'].message_type = _SHORTCUTCONTROLLERARCHIVE_SHORTCUTMAPENTRY
_PROPAGATEPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_PROPAGATEPRESETCOMMANDARCHIVE.fields_by_name['preset_change_command'].message_type = TSPMessages__pb2._REFERENCE
_SHORTCUTCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_SHORTCUTCOMMANDARCHIVE.fields_by_name['old_style'].message_type = TSPMessages__pb2._REFERENCE
_SHORTCUTCOMMANDARCHIVE.fields_by_name['new_style'].message_type = TSPMessages__pb2._REFERENCE
_ADDCUSTOMFORMATCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_ADDCUSTOMFORMATCOMMANDARCHIVE.fields_by_name['custom_format'].message_type = TSKArchives__pb2._CUSTOMFORMATARCHIVE
_ADDCUSTOMFORMATCOMMANDARCHIVE.fields_by_name['custom_format_key'].message_type = TSPMessages__pb2._UUID
_UPDATECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_UPDATECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['custom_format'].message_type = TSKArchives__pb2._CUSTOMFORMATARCHIVE
_UPDATECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['old_custom_format'].message_type = TSKArchives__pb2._CUSTOMFORMATARCHIVE
_UPDATECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['custom_format_key'].message_type = TSPMessages__pb2._UUID
_REPLACECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REPLACECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['custom_format'].message_type = TSKArchives__pb2._CUSTOMFORMATARCHIVE
_REPLACECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['custom_format_key'].message_type = TSPMessages__pb2._UUID
_REPLACECUSTOMFORMATCOMMANDARCHIVE.fields_by_name['replacement_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_NEEDSMEDIACOMPATIBILITYUPGRADECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CHANGEDOCUMENTLOCALECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CHANGEDOCUMENTLOCALECOMMANDARCHIVE.fields_by_name['old_formatting_symbols'].message_type = TSKArchives__pb2._FORMATTINGSYMBOLSARCHIVE
_CHANGEDOCUMENTLOCALECOMMANDARCHIVE.fields_by_name['new_formatting_symbols'].message_type = TSKArchives__pb2._FORMATTINGSYMBOLSARCHIVE
_INDUCEDVERIFYOBJECTSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INDUCEDVERIFYOBJECTSWITHSERVERCOMMANDARCHIVE.fields_by_name['object_id_list'].message_type = TSPMessages__pb2._UUID
_INDUCEDVERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INDUCEDVERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE.fields_by_name['server_operation_storage_entries'].message_type = TSKArchives__pb2._OPERATIONSTORAGEENTRY
_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE.fields_by_name['super'].message_type = TSWPCommandArchives__pb2._STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE
_REMOTEDATACHANGECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REMOTEDATACHANGECOMMANDARCHIVE.fields_by_name['value_map'].message_type = TSCEArchives__pb2._REMOTEDATAVALUEMAPARCHIVE
_REMOTEDATACHANGECOMMANDARCHIVE.fields_by_name['quotes'].message_type = TSCEArchives__pb2._STOCKARCHIVE
_GALLERYINFOSETVALUECOMMANDARCHIVE_PROPERTYVALUE.fields_by_name['caption_mode'].enum_type = _GALLERYINFOCAPTIONMODE
_GALLERYINFOSETVALUECOMMANDARCHIVE_PROPERTYVALUE.containing_type = _GALLERYINFOSETVALUECOMMANDARCHIVE
_GALLERYINFOSETVALUECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_GALLERYINFOSETVALUECOMMANDARCHIVE.fields_by_name['info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYINFOSETVALUECOMMANDARCHIVE.fields_by_name['property'].enum_type = _GALLERYINFOPROPERTY
_GALLERYINFOSETVALUECOMMANDARCHIVE.fields_by_name['value'].message_type = _GALLERYINFOSETVALUECOMMANDARCHIVE_PROPERTYVALUE
_GALLERYINFOSETVALUECOMMANDARCHIVE.fields_by_name['old_value'].message_type = _GALLERYINFOSETVALUECOMMANDARCHIVE_PROPERTYVALUE
_GALLERYITEMSETGEOMETRYCOMMAND.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_GALLERYITEMSETGEOMETRYCOMMAND.fields_by_name['item_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYITEMSETGEOMETRYCOMMAND.fields_by_name['offset'].message_type = TSPMessages__pb2._POINT
_GALLERYITEMSETGEOMETRYCOMMAND.fields_by_name['old_offset'].message_type = TSPMessages__pb2._POINT
_GALLERYITEM.fields_by_name['offset'].message_type = TSPMessages__pb2._POINT
_GALLERYITEM.fields_by_name['image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_GALLERYITEM.fields_by_name['thumbnail_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_GALLERYITEM.fields_by_name['image_adjustments'].message_type = TSDArchives__pb2._IMAGEADJUSTMENTSARCHIVE
_GALLERYITEM.fields_by_name['adjusted_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_GALLERYITEM.fields_by_name['thumbnail_adjusted_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_GALLERYITEM.fields_by_name['caption_storage'].message_type = TSPMessages__pb2._REFERENCE
_GALLERYINFO.fields_by_name['items'].message_type = TSPMessages__pb2._REFERENCE
_GALLERYINFO.fields_by_name['caption_mode'].enum_type = _GALLERYCAPTIONMODE
_GALLERYINFO.fields_by_name['caption_storage'].message_type = TSPMessages__pb2._REFERENCE
_GALLERYSELECTIONTRANSFORMER.fields_by_name['super'].message_type = TSDCommandArchives__pb2._DRAWABLESELECTIONTRANSFORMERARCHIVE
_GALLERYSELECTIONTRANSFORMER.fields_by_name['gallery_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYSELECTIONTRANSFORMER.fields_by_name['caption_storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYITEMSELECTION.fields_by_name['displayed_item'].message_type = TSPMessages__pb2._REFERENCE
_GALLERYITEMSELECTION.fields_by_name['items'].message_type = TSPMessages__pb2._REFERENCE
_GALLERYITEMSELECTIONTRANSFORMER.fields_by_name['transformer_helper'].message_type = _GALLERYITEMSELECTIONTRANSFORMERHELPER
_GALLERYITEMSELECTIONTRANSFORMER.fields_by_name['caption_storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYITEMSELECTIONTRANSFORMERHELPER.fields_by_name['displayed_item_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYITEMSELECTIONTRANSFORMERHELPER.fields_by_name['item_uuid_paths'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYITEMSETVALUECOMMAND_PROPERTYVALUE.fields_by_name['image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_GALLERYITEMSETVALUECOMMAND_PROPERTYVALUE.containing_type = _GALLERYITEMSETVALUECOMMAND
_GALLERYITEMSETVALUECOMMAND.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_GALLERYITEMSETVALUECOMMAND.fields_by_name['item_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_GALLERYITEMSETVALUECOMMAND.fields_by_name['property'].enum_type = _GALLERYITEMPROPERTY
_GALLERYITEMSETVALUECOMMAND.fields_by_name['value'].message_type = _GALLERYITEMSETVALUECOMMAND_PROPERTYVALUE
_GALLERYITEMSETVALUECOMMAND.fields_by_name['old_value'].message_type = _GALLERYITEMSETVALUECOMMAND_PROPERTYVALUE
_WEBVIDEOINFO.fields_by_name['poster_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_WEBVIDEOINFO.fields_by_name['attribution'].message_type = TSDArchives__pb2._ATTRIBUTION
_CAPTIONINFOARCHIVE.fields_by_name['super'].message_type = TSWPArchives__pb2._SHAPEINFOARCHIVE
_CAPTIONINFOARCHIVE.fields_by_name['placement'].message_type = TSPMessages__pb2._REFERENCE
_CAPTIONINFOARCHIVE.fields_by_name['childInfoKind'].enum_type = TSDCommandArchives__pb2._CAPTIONORTITLEKIND
_TITLEPLACEMENTCOMMANDARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._INFOCOMMANDARCHIVE
_TITLEPLACEMENTCOMMANDARCHIVE.fields_by_name['placing_child_info_kind'].enum_type = TSDCommandArchives__pb2._CAPTIONORTITLEKIND
_TITLEPLACEMENTCOMMANDARCHIVE.fields_by_name['placement'].message_type = TSPMessages__pb2._REFERENCE
_TITLEPLACEMENTCOMMANDARCHIVE.fields_by_name['old_placement'].message_type = TSPMessages__pb2._REFERENCE
DESCRIPTOR.message_types_by_name['DocumentArchive'] = _DOCUMENTARCHIVE
DESCRIPTOR.message_types_by_name['FunctionBrowserStateArchive'] = _FUNCTIONBROWSERSTATEARCHIVE
DESCRIPTOR.message_types_by_name['ThemePresetsArchive'] = _THEMEPRESETSARCHIVE
DESCRIPTOR.message_types_by_name['ShortcutControllerArchive'] = _SHORTCUTCONTROLLERARCHIVE
DESCRIPTOR.message_types_by_name['PropagatePresetCommandArchive'] = _PROPAGATEPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ShortcutCommandArchive'] = _SHORTCUTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['AddCustomFormatCommandArchive'] = _ADDCUSTOMFORMATCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['UpdateCustomFormatCommandArchive'] = _UPDATECUSTOMFORMATCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ReplaceCustomFormatCommandArchive'] = _REPLACECUSTOMFORMATCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['NeedsMediaCompatibilityUpgradeCommandArchive'] = _NEEDSMEDIACOMPATIBILITYUPGRADECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ChangeDocumentLocaleCommandArchive'] = _CHANGEDOCUMENTLOCALECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyObjectsWithServerCommandArchive'] = _INDUCEDVERIFYOBJECTSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyTransformHistoryWithServerCommandArchive'] = _INDUCEDVERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleUpdatePropertyMapCommandArchive'] = _STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['RemoteDataChangeCommandArchive'] = _REMOTEDATACHANGECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['GalleryInfoSetValueCommandArchive'] = _GALLERYINFOSETVALUECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['GalleryItemSetGeometryCommand'] = _GALLERYITEMSETGEOMETRYCOMMAND
DESCRIPTOR.message_types_by_name['GalleryItem'] = _GALLERYITEM
DESCRIPTOR.message_types_by_name['GalleryInfo'] = _GALLERYINFO
DESCRIPTOR.message_types_by_name['GallerySelectionTransformer'] = _GALLERYSELECTIONTRANSFORMER
DESCRIPTOR.message_types_by_name['GalleryItemSelection'] = _GALLERYITEMSELECTION
DESCRIPTOR.message_types_by_name['GalleryItemSelectionTransformer'] = _GALLERYITEMSELECTIONTRANSFORMER
DESCRIPTOR.message_types_by_name['GalleryItemSelectionTransformerHelper'] = _GALLERYITEMSELECTIONTRANSFORMERHELPER
DESCRIPTOR.message_types_by_name['GalleryItemSetValueCommand'] = _GALLERYITEMSETVALUECOMMAND
DESCRIPTOR.message_types_by_name['WebVideoInfo'] = _WEBVIDEOINFO
DESCRIPTOR.message_types_by_name['CaptionPlacementArchive'] = _CAPTIONPLACEMENTARCHIVE
DESCRIPTOR.message_types_by_name['CaptionInfoArchive'] = _CAPTIONINFOARCHIVE
DESCRIPTOR.message_types_by_name['TitlePlacementCommandArchive'] = _TITLEPLACEMENTCOMMANDARCHIVE
DESCRIPTOR.enum_types_by_name['GalleryInfoCaptionMode'] = _GALLERYINFOCAPTIONMODE
DESCRIPTOR.enum_types_by_name['GalleryInfoProperty'] = _GALLERYINFOPROPERTY
DESCRIPTOR.enum_types_by_name['GalleryCaptionMode'] = _GALLERYCAPTIONMODE
DESCRIPTOR.enum_types_by_name['GalleryItemProperty'] = _GALLERYITEMPROPERTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DocumentArchive = _reflection.GeneratedProtocolMessageType('DocumentArchive', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.DocumentArchive)
  ))
_sym_db.RegisterMessage(DocumentArchive)

FunctionBrowserStateArchive = _reflection.GeneratedProtocolMessageType('FunctionBrowserStateArchive', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTIONBROWSERSTATEARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.FunctionBrowserStateArchive)
  ))
_sym_db.RegisterMessage(FunctionBrowserStateArchive)

ThemePresetsArchive = _reflection.GeneratedProtocolMessageType('ThemePresetsArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEPRESETSARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.ThemePresetsArchive)
  ))
_sym_db.RegisterMessage(ThemePresetsArchive)

ShortcutControllerArchive = _reflection.GeneratedProtocolMessageType('ShortcutControllerArchive', (_message.Message,), dict(

  ShortcutMapEntry = _reflection.GeneratedProtocolMessageType('ShortcutMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _SHORTCUTCONTROLLERARCHIVE_SHORTCUTMAPENTRY,
    __module__ = 'TSAArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSA.ShortcutControllerArchive.ShortcutMapEntry)
    ))
  ,
  DESCRIPTOR = _SHORTCUTCONTROLLERARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.ShortcutControllerArchive)
  ))
_sym_db.RegisterMessage(ShortcutControllerArchive)
_sym_db.RegisterMessage(ShortcutControllerArchive.ShortcutMapEntry)

PropagatePresetCommandArchive = _reflection.GeneratedProtocolMessageType('PropagatePresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROPAGATEPRESETCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.PropagatePresetCommandArchive)
  ))
_sym_db.RegisterMessage(PropagatePresetCommandArchive)

ShortcutCommandArchive = _reflection.GeneratedProtocolMessageType('ShortcutCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHORTCUTCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.ShortcutCommandArchive)
  ))
_sym_db.RegisterMessage(ShortcutCommandArchive)

AddCustomFormatCommandArchive = _reflection.GeneratedProtocolMessageType('AddCustomFormatCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _ADDCUSTOMFORMATCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.AddCustomFormatCommandArchive)
  ))
_sym_db.RegisterMessage(AddCustomFormatCommandArchive)

UpdateCustomFormatCommandArchive = _reflection.GeneratedProtocolMessageType('UpdateCustomFormatCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECUSTOMFORMATCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.UpdateCustomFormatCommandArchive)
  ))
_sym_db.RegisterMessage(UpdateCustomFormatCommandArchive)

ReplaceCustomFormatCommandArchive = _reflection.GeneratedProtocolMessageType('ReplaceCustomFormatCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REPLACECUSTOMFORMATCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.ReplaceCustomFormatCommandArchive)
  ))
_sym_db.RegisterMessage(ReplaceCustomFormatCommandArchive)

NeedsMediaCompatibilityUpgradeCommandArchive = _reflection.GeneratedProtocolMessageType('NeedsMediaCompatibilityUpgradeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _NEEDSMEDIACOMPATIBILITYUPGRADECOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.NeedsMediaCompatibilityUpgradeCommandArchive)
  ))
_sym_db.RegisterMessage(NeedsMediaCompatibilityUpgradeCommandArchive)

ChangeDocumentLocaleCommandArchive = _reflection.GeneratedProtocolMessageType('ChangeDocumentLocaleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEDOCUMENTLOCALECOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.ChangeDocumentLocaleCommandArchive)
  ))
_sym_db.RegisterMessage(ChangeDocumentLocaleCommandArchive)

InducedVerifyObjectsWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyObjectsWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYOBJECTSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.InducedVerifyObjectsWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyObjectsWithServerCommandArchive)

InducedVerifyTransformHistoryWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyTransformHistoryWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.InducedVerifyTransformHistoryWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyTransformHistoryWithServerCommandArchive)

StyleUpdatePropertyMapCommandArchive = _reflection.GeneratedProtocolMessageType('StyleUpdatePropertyMapCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.StyleUpdatePropertyMapCommandArchive)
  ))
_sym_db.RegisterMessage(StyleUpdatePropertyMapCommandArchive)

RemoteDataChangeCommandArchive = _reflection.GeneratedProtocolMessageType('RemoteDataChangeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOTEDATACHANGECOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.RemoteDataChangeCommandArchive)
  ))
_sym_db.RegisterMessage(RemoteDataChangeCommandArchive)

GalleryInfoSetValueCommandArchive = _reflection.GeneratedProtocolMessageType('GalleryInfoSetValueCommandArchive', (_message.Message,), dict(

  PropertyValue = _reflection.GeneratedProtocolMessageType('PropertyValue', (_message.Message,), dict(
    DESCRIPTOR = _GALLERYINFOSETVALUECOMMANDARCHIVE_PROPERTYVALUE,
    __module__ = 'TSAArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSA.GalleryInfoSetValueCommandArchive.PropertyValue)
    ))
  ,
  DESCRIPTOR = _GALLERYINFOSETVALUECOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryInfoSetValueCommandArchive)
  ))
_sym_db.RegisterMessage(GalleryInfoSetValueCommandArchive)
_sym_db.RegisterMessage(GalleryInfoSetValueCommandArchive.PropertyValue)

GalleryItemSetGeometryCommand = _reflection.GeneratedProtocolMessageType('GalleryItemSetGeometryCommand', (_message.Message,), dict(
  DESCRIPTOR = _GALLERYITEMSETGEOMETRYCOMMAND,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryItemSetGeometryCommand)
  ))
_sym_db.RegisterMessage(GalleryItemSetGeometryCommand)

GalleryItem = _reflection.GeneratedProtocolMessageType('GalleryItem', (_message.Message,), dict(
  DESCRIPTOR = _GALLERYITEM,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryItem)
  ))
_sym_db.RegisterMessage(GalleryItem)

GalleryInfo = _reflection.GeneratedProtocolMessageType('GalleryInfo', (_message.Message,), dict(
  DESCRIPTOR = _GALLERYINFO,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryInfo)
  ))
_sym_db.RegisterMessage(GalleryInfo)

GallerySelectionTransformer = _reflection.GeneratedProtocolMessageType('GallerySelectionTransformer', (_message.Message,), dict(
  DESCRIPTOR = _GALLERYSELECTIONTRANSFORMER,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GallerySelectionTransformer)
  ))
_sym_db.RegisterMessage(GallerySelectionTransformer)

GalleryItemSelection = _reflection.GeneratedProtocolMessageType('GalleryItemSelection', (_message.Message,), dict(
  DESCRIPTOR = _GALLERYITEMSELECTION,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryItemSelection)
  ))
_sym_db.RegisterMessage(GalleryItemSelection)

GalleryItemSelectionTransformer = _reflection.GeneratedProtocolMessageType('GalleryItemSelectionTransformer', (_message.Message,), dict(
  DESCRIPTOR = _GALLERYITEMSELECTIONTRANSFORMER,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryItemSelectionTransformer)
  ))
_sym_db.RegisterMessage(GalleryItemSelectionTransformer)

GalleryItemSelectionTransformerHelper = _reflection.GeneratedProtocolMessageType('GalleryItemSelectionTransformerHelper', (_message.Message,), dict(
  DESCRIPTOR = _GALLERYITEMSELECTIONTRANSFORMERHELPER,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryItemSelectionTransformerHelper)
  ))
_sym_db.RegisterMessage(GalleryItemSelectionTransformerHelper)

GalleryItemSetValueCommand = _reflection.GeneratedProtocolMessageType('GalleryItemSetValueCommand', (_message.Message,), dict(

  PropertyValue = _reflection.GeneratedProtocolMessageType('PropertyValue', (_message.Message,), dict(
    DESCRIPTOR = _GALLERYITEMSETVALUECOMMAND_PROPERTYVALUE,
    __module__ = 'TSAArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSA.GalleryItemSetValueCommand.PropertyValue)
    ))
  ,
  DESCRIPTOR = _GALLERYITEMSETVALUECOMMAND,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.GalleryItemSetValueCommand)
  ))
_sym_db.RegisterMessage(GalleryItemSetValueCommand)
_sym_db.RegisterMessage(GalleryItemSetValueCommand.PropertyValue)

WebVideoInfo = _reflection.GeneratedProtocolMessageType('WebVideoInfo', (_message.Message,), dict(
  DESCRIPTOR = _WEBVIDEOINFO,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.WebVideoInfo)
  ))
_sym_db.RegisterMessage(WebVideoInfo)

CaptionPlacementArchive = _reflection.GeneratedProtocolMessageType('CaptionPlacementArchive', (_message.Message,), dict(
  DESCRIPTOR = _CAPTIONPLACEMENTARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.CaptionPlacementArchive)
  ))
_sym_db.RegisterMessage(CaptionPlacementArchive)

CaptionInfoArchive = _reflection.GeneratedProtocolMessageType('CaptionInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _CAPTIONINFOARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.CaptionInfoArchive)
  ))
_sym_db.RegisterMessage(CaptionInfoArchive)

TitlePlacementCommandArchive = _reflection.GeneratedProtocolMessageType('TitlePlacementCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _TITLEPLACEMENTCOMMANDARCHIVE,
  __module__ = 'TSAArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSA.TitlePlacementCommandArchive)
  ))
_sym_db.RegisterMessage(TitlePlacementCommandArchive)

_THEMEPRESETSARCHIVE.extensions_by_name['extension'].message_type = _THEMEPRESETSARCHIVE
TSSArchives__pb2.ThemeArchive.RegisterExtension(_THEMEPRESETSARCHIVE.extensions_by_name['extension'])
_GALLERYINFO.extensions_by_name['gallery_info'].message_type = _GALLERYINFO
TSDArchives__pb2.ImageArchive.RegisterExtension(_GALLERYINFO.extensions_by_name['gallery_info'])
_WEBVIDEOINFO.extensions_by_name['web_video_info'].message_type = _WEBVIDEOINFO
TSDArchives__pb2.ImageArchive.RegisterExtension(_WEBVIDEOINFO.extensions_by_name['web_video_info'])

# @@protoc_insertion_point(module_scope)
